@@ -1,7 +1,6 @@
 import sys
-import subprocess
 
-from pycellbase.commons import get, deprecated, wrapper
+from pycellbase.commons import get, deprecated
 
 
 class _ParentRestClient(object):
@@ -11,12 +10,7 @@ class _ParentRestClient(object):
         self._configuration = configuration
         self._subcategory = subcategory
         self._category = category
-        retries = 5
 
-        # decorates the REST verbs with retries
-        self._get = wrapper(self._get, retries)
-        self._post = wrapper(self._post, retries)
-        
     def _get(self, resource, query_id=None, options=None):
         """Queries the REST service and returns the result"""
         response = get(session=self._session,
@@ -75,11 +69,13 @@ class _ParentRestClient(object):
                          and method_swag in path]
             if not path_info:
                 continue
+            # TODO This is a temporary check to fix POST methods, that should be removed.
+            if 'get' not in path_info[0]:
+                continue
             if 'summary' not in path_info[0]['get']:
                 continue
             desc = path_info[0]['get']['summary']
-            desc = desc.replace('http://bioinfo.hpc.cam.ac.uk/cellbase',
-                                self._configuration.host)
+            desc = desc.replace('http://bioinfo.hpc.cam.ac.uk/cellbase', self._configuration.host)
             sys.stdout.write(text.format(indent=' ' * 4,
                                          bullet='-',
                                          name=method,
